From 36d5186b89408edfc91d860942035b2ddea367d9 Mon Sep 17 00:00:00 2001
From: Rohit Yadav <rohityadav89@gmail.com>
Date: Mon, 27 Dec 2010 04:43:14 +0530
Subject: [PATCH 2/5] Build script to configure and compile libvlcjni.

---
 extras/package/android/make_libvlcjni.sh |   76 +++++++++++++++++++++++++++---
 1 files changed, 69 insertions(+), 7 deletions(-)

diff --git a/extras/package/android/make_libvlcjni.sh b/extras/package/android/make_libvlcjni.sh
index db99353..ea11ca6 100755
--- a/extras/package/android/make_libvlcjni.sh
+++ b/extras/package/android/make_libvlcjni.sh
@@ -1,17 +1,79 @@
 #!/bin/sh
 
-if [ -z "$ANDROID_NDK" ]; then
-    echo "Set your ANDROID_NDK environment variable"
+# Get the VLC build path
+if [ "x$1" = "x" ]; then
+    echo "This script needs the vlc build path"
     exit 1
 fi
+VLC_BUILD_PATH=$1
 
+# Get the VLC contrib build directory
+if [ "x$2" = "x" ]; then
+    echo "This script needs the contrib build path"
+    exit 1
+fi
+VLC_CONTRIB_PATH=$2
 
-cd libvlcjni
-$ANDROID_NDK/ndk-build
+if [ -z "$ANDROID_NDK" ]; then
+    echo "Please define your ANDROID_NDK environment variable"
+    exit 1
+fi
+
+# Do we have an absolute path ?
+prefix=""
+if [ `echo $VLC_BUILD_PATH | head -c 1` != "/" ]; then
+    prefix="../"
+fi
 
-if [  ! -d "../vlc-android/libs/armeabi" ]; then
-    mkdir -p ../vlc-android/libs/armeabi/
+# If the contrib path is not absolute, change it
+if [ `echo $VLC_CONTRIB_PATH | head -c 1` != "/" ]; then
+    VLC_CONTRIB_PATH="../$VLC_CONTRIB_PATH"
 fi
 
-cp -v libs/armeabi/libvlcjni.so ../vlc-android/libs/armeabi/
+# Lookup for every static modules in the VLC build path
+modules=`find $VLC_BUILD_PATH/modules -name '*.a'|grep -v dvdnav|grep -v mmap|grep -v spatializer`
+
+# Build the list of modules
+LDFLAGS=""
+DEFINITION=""
+BUILTINS="const void *vlc_builtins_modules[] = {\n"
+
+for file in $modules; do
+    name=`echo $file | sed 's/.*\.libs\/lib//' | sed 's/_plugin\.a//'`
+
+    LDFLAGS=$LDFLAGS"$prefix$file "
+    DEFINITION=$DEFINITION"vlc_declare_plugin(${name});\n"
+    BUILTINS=$BUILTINS"    vlc_plugin(${name}),\n"
+done;
 
+BUILTINS=$BUILTINS"    NULL\n"
+BUILTINS=$BUILTINS"};\n"
+
+LIBVLCJNI_ROOT=vlc-android
+
+# Write the right files
+rm -f $LIBVLCJNI_ROOT/jni/libvlcjni.h
+echo "// libvlcjni.h\n// Autogenerated from the list of modules\n" > $LIBVLCJNI_ROOT/jni/libvlcjni.h
+echo "$DEFINITION\n" >> $LIBVLCJNI_ROOT/jni/libvlcjni.h
+echo $BUILTINS >> $LIBVLCJNI_ROOT/jni/libvlcjni.h
+
+rm -f $LIBVLCJNI_ROOT/jni/Android.mk
+echo "LOCAL_PATH := \$(call my-dir)
+
+include \$(CLEAR_VARS)
+
+LOCAL_MODULE    := libvlcjni
+LOCAL_SRC_FILES := libvlcjni.c
+LOCAL_C_INCLUDES := \$(LOCAL_PATH)/../../../../../include
+LOCAL_LDLIBS := -L$ANDROID_NDK/platforms/android-9/arch-arm/usr/lib -L$VLC_CONTRIB_PATH/lib $LDFLAGS $prefix$VLC_BUILD_PATH/src/.libs/libvlc.a $prefix$VLC_BUILD_PATH/src/.libs/libvlccore.a -ldl -lz -lm -logg -lvorbisenc -lvorbis -lFLAC -lspeex -ltheora -lavformat -lavcodec -lavcore -lavutil -lpostproc -lswscale -lmpeg2 -lgcc -lpng -logg -ldca -ldvbpsi -ltwolame -lkate -lOpenSLES -lGLESv1_CM -lEGL -landroid
+
+include \$(BUILD_SHARED_LIBRARY)
+" > $LIBVLCJNI_ROOT/jni/Android.mk
+
+if [ -z "$ANDROID_NDK" ]; then
+    echo "Set your ANDROID_NDK environment variable"
+    exit 1
+fi
+
+cd $LIBVLCJNI_ROOT
+$ANDROID_NDK/ndk-build
-- 
1.7.1

